@@ -4,16 +4,20 @@ import (
 	"context"
 	"fmt"
 	"net/http"
+	"slices"
+	"strconv"
+	"time"
 
 	"github.com/putdotio/go-putio/putio"
 	"github.com/rclone/rclone/fs/fserrors"
+	"github.com/rclone/rclone/lib/pacer"
 )
 
-func checkStatusCode(resp *http.Response, expected int) error {
-	if resp.StatusCode != expected {
-		return &statusCodeError{response: resp}
+func checkStatusCode(resp *http.Response, expected ...int) error {
+	if slices.Contains(expected, resp.StatusCode) {
+		return nil
 	}
-	return nil
+	return &statusCodeError{response: resp}
 }
 
 type statusCodeError struct {
@@ -24,8 +28,10 @@ func (e *statusCodeError) Error() string {
 	return fmt.Sprintf("unexpected status code (%d) response while doing %s to %s", e.response.StatusCode, e.response.Request.Method, e.response.Request.URL.String())
 }
 
+// This method is called from fserrors.ShouldRetry() to determine if an error should be retried.
+// Some errors (e.g. 429 Too Many Requests) are handled before this step, so they are not included here.
 func (e *statusCodeError) Temporary() bool {
-	return e.response.StatusCode == 429 || e.response.StatusCode >= 500
+	return e.response.StatusCode >= 500
 }
 
 // shouldRetry returns a boolean as to whether this err deserves to be
@@ -40,6 +46,16 @@ func shouldRetry(ctx context.Context, err error) (bool, error) {
 	if perr, ok := err.(*putio.ErrorResponse); ok {
 		err = &statusCodeError{response: perr.Response}
 	}
+	if scerr, ok := err.(*statusCodeError); ok && scerr.response.StatusCode == 429 {
+		delay := defaultRateLimitSleep
+		header := scerr.response.Header.Get("x-ratelimit-reset")
+		if header != "" {
+			if resetTime, cerr := strconv.ParseInt(header, 10, 64); cerr == nil {
+				delay = time.Until(time.Unix(resetTime+1, 0))
+			}
+		}
+		return true, pacer.RetryAfterError(scerr, delay)
+	}
 	if fserrors.ShouldRetry(err) {
 		return true, err
 	}
