@@ -16,12 +16,12 @@ func init() {
 var commandDefinition = &cobra.Command{
 	Use:   "cleanup remote:path",
 	Short: `Clean up the remote if possible.`,
-	Long: `
-Clean up the remote if possible.  Empty the trash or delete old file
+	Long: `Clean up the remote if possible.  Empty the trash or delete old file
 versions. Not supported by all remotes.
 `,
 	Annotations: map[string]string{
 		"versionIntroduced": "v1.31",
+		"groups":            "Important",
 	},
 	Run: func(command *cobra.Command, args []string) {
 		cmd.CheckArgs(1, 1, command, args)
