@@ -27,8 +27,7 @@ func init() {
 var commandDefinition = &cobra.Command{
 	Use:   "link remote:path",
 	Short: `Generate public link to file/folder.`,
-	Long: `rclone link will create, retrieve or remove a public link to the given
-file or folder.
+	Long: `Create, retrieve or remove a public link to the given file or folder.
 
     rclone link remote:path/to/file
     rclone link remote:path/to/folder/
