@@ -6,6 +6,8 @@ package ncdu
 import (
 	"context"
 	"fmt"
+	"log/slog"
+	"os"
 	"path"
 	"reflect"
 	"sort"
@@ -185,7 +187,7 @@ func (u *UI) Print(x, y int, style tcell.Style, msg string) {
 }
 
 // Printf a string
-func (u *UI) Printf(x, y int, style tcell.Style, format string, args ...interface{}) {
+func (u *UI) Printf(x, y int, style tcell.Style, format string, args ...any) {
 	s := fmt.Sprintf(format, args...)
 	u.Print(x, y, style, s)
 }
@@ -207,7 +209,7 @@ func (u *UI) Line(x, y, xmax int, style tcell.Style, spacer rune, msg string) {
 }
 
 // Linef a string
-func (u *UI) Linef(x, y, xmax int, style tcell.Style, spacer rune, format string, args ...interface{}) {
+func (u *UI) Linef(x, y, xmax int, style tcell.Style, spacer rune, format string, args ...any) {
 	s := fmt.Sprintf(format, args...)
 	u.Line(x, y, xmax, style, spacer, s)
 }
@@ -273,11 +275,7 @@ func (u *UI) Box() {
 	xmax := x + boxWidth
 	if len(u.boxMenu) != 0 {
 		count := lineOptionLength(u.boxMenu)
-		if x+boxWidth > x+count {
-			xmax = x + boxWidth
-		} else {
-			xmax = x + count
-		}
+		xmax = max(x+boxWidth, x+count)
 	}
 	ymax := y + len(u.boxText)
 
@@ -929,23 +927,19 @@ func (u *UI) Run() error {
 		return fmt.Errorf("screen init: %w", err)
 	}
 
-	// Hijack fs.LogOutput so that it doesn't corrupt the screen.
-	if logOutput := fs.LogOutput; !log.Redirected() {
-		type log struct {
-			text  string
-			level fs.LogLevel
-		}
-		var logs []log
-		fs.LogOutput = func(level fs.LogLevel, text string) {
+	// Hijack log output so that it doesn't corrupt the screen.
+	if !log.Redirected() {
+		var logs []string
+		log.Handler.SetOutput(func(level slog.Level, text string) {
 			if len(logs) > 100 {
 				logs = logs[len(logs)-100:]
 			}
-			logs = append(logs, log{level: level, text: text})
-		}
+			logs = append(logs, text)
+		})
 		defer func() {
-			fs.LogOutput = logOutput
-			for i := range logs {
-				logOutput(logs[i].level, logs[i].text)
+			log.Handler.ResetOutput()
+			for _, text := range logs {
+				_, _ = os.Stderr.WriteString(text)
 			}
 		}()
 	}
