@@ -3,21 +3,21 @@ package http
 import (
 	"bytes"
 	"embed"
+	"fmt"
 	"html/template"
-	"log"
 	"os"
 	"strings"
 	"time"
 
 	"github.com/spf13/pflag"
 
+	"github.com/rclone/rclone/fs"
 	"github.com/rclone/rclone/fs/config/flags"
 )
 
 // TemplateHelp returns a string that describes how to use a custom template
 func TemplateHelp(prefix string) string {
-	help := `
-#### Template
+	help := `#### Template
 
 ` + "`--{{ .Prefix }}template`" + ` allows a user to specify a custom markup template for HTTP
 and WebDAV serve functions.  The server exports the following markup
@@ -52,11 +52,12 @@ be used to render HTML based on specific conditions.
 | contains    | Checks whether a given substring is present or not in a given string. |
 | hasPrefix   | Checks whether the given string begins with the specified prefix. |
 | hasSuffix   | Checks whether the given string end with the specified suffix. |
+
 `
 
 	tmpl, err := template.New("template help").Parse(help)
 	if err != nil {
-		log.Fatal("Fatal error parsing template", err)
+		fs.Fatal(nil, fmt.Sprint("Fatal error parsing template", err))
 	}
 
 	data := struct {
@@ -67,14 +68,21 @@ be used to render HTML based on specific conditions.
 	buf := &bytes.Buffer{}
 	err = tmpl.Execute(buf, data)
 	if err != nil {
-		log.Fatal("Fatal error executing template", err)
+		fs.Fatal(nil, fmt.Sprint("Fatal error executing template", err))
 	}
 	return buf.String()
 }
 
+// TemplateConfigInfo descripts the Options in use
+var TemplateConfigInfo = fs.Options{{
+	Name:    "template",
+	Default: "",
+	Help:    "User-specified template",
+}}
+
 // TemplateConfig for the templating functionality
 type TemplateConfig struct {
-	Path string
+	Path string `config:"template"`
 }
 
 // AddFlagsPrefix for the templating functionality
@@ -88,6 +96,9 @@ func AddTemplateFlagsPrefix(flagSet *pflag.FlagSet, prefix string, cfg *Template
 }
 
 // DefaultTemplateCfg returns a new config which can be customized by command line flags
+//
+// Note that this needs to be kept in sync with TemplateConfigInfo above and
+// can be removed when all callers have been converted.
 func DefaultTemplateCfg() TemplateConfig {
 	return TemplateConfig{}
 }
